# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient


class AssignmentsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_assignment(self, **kwargs):  # noqa: E501
        """Adds a new Assignment.  # noqa: E501

        Adds a new Assignment.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_assignment(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddAssignmentRequest body:
        :return: AssignmentImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_assignment_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_assignment_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_assignment_with_http_info(self, **kwargs):  # noqa: E501
        """Adds a new Assignment.  # noqa: E501

        Adds a new Assignment.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_assignment_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddAssignmentRequest body:
        :return: AssignmentImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_assignment" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/assignments', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssignmentImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_assignment(self, assignment_id, **kwargs):  # noqa: E501
        """Changes the assignment with the information that is provided in the request.  # noqa: E501

        Changes the assignment with the information that is provided in the request. Only properties that are specified in the request and are not NULL are updated. All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_assignment(assignment_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assignment_id: The unique identifier of the Assignment. (required)
        :param ChangeAssignmentRequest body:
        :return: AssignmentImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_assignment_with_http_info(assignment_id, **kwargs)  # noqa: E501
        else:
            (data) = self.change_assignment_with_http_info(assignment_id, **kwargs)  # noqa: E501
            return data

    def change_assignment_with_http_info(self, assignment_id, **kwargs):  # noqa: E501
        """Changes the assignment with the information that is provided in the request.  # noqa: E501

        Changes the assignment with the information that is provided in the request. Only properties that are specified in the request and are not NULL are updated. All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_assignment_with_http_info(assignment_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assignment_id: The unique identifier of the Assignment. (required)
        :param ChangeAssignmentRequest body:
        :return: AssignmentImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['assignment_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_assignment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'assignment_id' is set
        if ('assignment_id' not in params or
                params['assignment_id'] is None):
            raise ValueError("Missing the required parameter `assignment_id` when calling `change_assignment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'assignment_id' in params:
            path_params['assignmentId'] = params['assignment_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/assignments/{assignmentId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssignmentImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_assignments_for_resource(self, **kwargs):  # noqa: E501
        """Find the assignments where a given resource is assigned.  # noqa: E501

        Find the assignments where a given resource is assigned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_assignments_for_resource(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str resource_id: The ID of the resource on which the assignment applies.
        :param str resource_type: The type of resource that is assigned.
        :return: list[AssignmentImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_assignments_for_resource_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.find_assignments_for_resource_with_http_info(**kwargs)  # noqa: E501
            return data

    def find_assignments_for_resource_with_http_info(self, **kwargs):  # noqa: E501
        """Find the assignments where a given resource is assigned.  # noqa: E501

        Find the assignments where a given resource is assigned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_assignments_for_resource_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str resource_id: The ID of the resource on which the assignment applies.
        :param str resource_type: The type of resource that is assigned.
        :return: list[AssignmentImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['resource_id', 'resource_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_assignments_for_resource" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'resource_id' in params:
            query_params.append(('resourceId', params['resource_id']))  # noqa: E501
        if 'resource_type' in params:
            query_params.append(('resourceType', params['resource_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/assignments/forResource', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AssignmentImpl]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_assignments_for_asset(self, asset_id, **kwargs):  # noqa: E501
        """Returns the Assignment identified by the given Asset.  # noqa: E501

        Returns the Assignment identified by the given Asset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_assignments_for_asset(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The unique identifier of the Asset. (required)
        :return: AssignmentImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_assignments_for_asset_with_http_info(asset_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_assignments_for_asset_with_http_info(asset_id, **kwargs)  # noqa: E501
            return data

    def get_assignments_for_asset_with_http_info(self, asset_id, **kwargs):  # noqa: E501
        """Returns the Assignment identified by the given Asset.  # noqa: E501

        Returns the Assignment identified by the given Asset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_assignments_for_asset_with_http_info(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The unique identifier of the Asset. (required)
        :return: AssignmentImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['asset_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_assignments_for_asset" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'asset_id' is set
        if ('asset_id' not in params or
                params['asset_id'] is None):
            raise ValueError("Missing the required parameter `asset_id` when calling `get_assignments_for_asset`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset_id' in params:
            path_params['assetId'] = params['asset_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/assignments/asset/{assetId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssignmentImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_assignments_for_asset_type(self, asset_type_id, **kwargs):  # noqa: E501
        """Returns Assignments for given asset type id.  # noqa: E501

        Returns Assignments for given asset type id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_assignments_for_asset_type(asset_type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_type_id: The unique identifier of the AssetType. (required)
        :return: list[AssignmentImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_assignments_for_asset_type_with_http_info(asset_type_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_assignments_for_asset_type_with_http_info(asset_type_id, **kwargs)  # noqa: E501
            return data

    def get_assignments_for_asset_type_with_http_info(self, asset_type_id, **kwargs):  # noqa: E501
        """Returns Assignments for given asset type id.  # noqa: E501

        Returns Assignments for given asset type id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_assignments_for_asset_type_with_http_info(asset_type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_type_id: The unique identifier of the AssetType. (required)
        :return: list[AssignmentImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['asset_type_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_assignments_for_asset_type" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'asset_type_id' is set
        if ('asset_type_id' not in params or
                params['asset_type_id'] is None):
            raise ValueError("Missing the required parameter `asset_type_id` when calling `get_assignments_for_asset_type`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset_type_id' in params:
            path_params['assetTypeId'] = params['asset_type_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/assignments/assetType/{assetTypeId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AssignmentImpl]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_available_asset_types_for_domain(self, domain_id, **kwargs):  # noqa: E501
        """Returns available asset types for domain identified by given id.  # noqa: E501

        Returns available asset types for domain identified by given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_available_asset_types_for_domain(domain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str domain_id: The unique identifier of the Domain. (required)
        :return: list[AssetTypeImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_available_asset_types_for_domain_with_http_info(domain_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_available_asset_types_for_domain_with_http_info(domain_id, **kwargs)  # noqa: E501
            return data

    def get_available_asset_types_for_domain_with_http_info(self, domain_id, **kwargs):  # noqa: E501
        """Returns available asset types for domain identified by given id.  # noqa: E501

        Returns available asset types for domain identified by given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_available_asset_types_for_domain_with_http_info(domain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str domain_id: The unique identifier of the Domain. (required)
        :return: list[AssetTypeImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['domain_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_available_asset_types_for_domain" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'domain_id' is set
        if ('domain_id' not in params or
                params['domain_id'] is None):
            raise ValueError("Missing the required parameter `domain_id` when calling `get_available_asset_types_for_domain`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'domain_id' in params:
            path_params['domainId'] = params['domain_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/assignments/domain/{domainId}/assetTypes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AssetTypeImpl]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_available_attribute_types_for_asset(self, asset_id, **kwargs):  # noqa: E501
        """Returns available attribute types for asset identified by given id.  # noqa: E501

        Returns available attribute types for asset identified by given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_available_attribute_types_for_asset(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The unique identifier of the Asset. (required)
        :return: list[AttributeType]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_available_attribute_types_for_asset_with_http_info(asset_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_available_attribute_types_for_asset_with_http_info(asset_id, **kwargs)  # noqa: E501
            return data

    def get_available_attribute_types_for_asset_with_http_info(self, asset_id, **kwargs):  # noqa: E501
        """Returns available attribute types for asset identified by given id.  # noqa: E501

        Returns available attribute types for asset identified by given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_available_attribute_types_for_asset_with_http_info(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The unique identifier of the Asset. (required)
        :return: list[AttributeType]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['asset_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_available_attribute_types_for_asset" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'asset_id' is set
        if ('asset_id' not in params or
                params['asset_id'] is None):
            raise ValueError("Missing the required parameter `asset_id` when calling `get_available_attribute_types_for_asset`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset_id' in params:
            path_params['assetId'] = params['asset_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/assignments/asset/{assetId}/attributeTypes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AttributeType]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_available_complex_relation_types_for_asset(self, asset_id, **kwargs):  # noqa: E501
        """Returns the available ComplexRelationTypes for the Asset identified by the given id.  # noqa: E501

        Returns the available ComplexRelationTypes for the Asset identified by the given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_available_complex_relation_types_for_asset(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The unique identifier of the Asset. (required)
        :return: list[ComplexRelationTypeImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_available_complex_relation_types_for_asset_with_http_info(asset_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_available_complex_relation_types_for_asset_with_http_info(asset_id, **kwargs)  # noqa: E501
            return data

    def get_available_complex_relation_types_for_asset_with_http_info(self, asset_id, **kwargs):  # noqa: E501
        """Returns the available ComplexRelationTypes for the Asset identified by the given id.  # noqa: E501

        Returns the available ComplexRelationTypes for the Asset identified by the given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_available_complex_relation_types_for_asset_with_http_info(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The unique identifier of the Asset. (required)
        :return: list[ComplexRelationTypeImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['asset_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_available_complex_relation_types_for_asset" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'asset_id' is set
        if ('asset_id' not in params or
                params['asset_id'] is None):
            raise ValueError("Missing the required parameter `asset_id` when calling `get_available_complex_relation_types_for_asset`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset_id' in params:
            path_params['assetId'] = params['asset_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/assignments/asset/{assetId}/complexRelationTypes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ComplexRelationTypeImpl]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_available_relation_types_for_asset(self, asset_id, **kwargs):  # noqa: E501
        """Returns the available RelationTypes for the Asset identified by the given id.  # noqa: E501

        Returns the available RelationTypes for the Asset identified by the given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_available_relation_types_for_asset(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The unique identifier of the Asset. (required)
        :return: list[RelationTypeImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_available_relation_types_for_asset_with_http_info(asset_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_available_relation_types_for_asset_with_http_info(asset_id, **kwargs)  # noqa: E501
            return data

    def get_available_relation_types_for_asset_with_http_info(self, asset_id, **kwargs):  # noqa: E501
        """Returns the available RelationTypes for the Asset identified by the given id.  # noqa: E501

        Returns the available RelationTypes for the Asset identified by the given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_available_relation_types_for_asset_with_http_info(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: The unique identifier of the Asset. (required)
        :return: list[RelationTypeImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['asset_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_available_relation_types_for_asset" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'asset_id' is set
        if ('asset_id' not in params or
                params['asset_id'] is None):
            raise ValueError("Missing the required parameter `asset_id` when calling `get_available_relation_types_for_asset`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset_id' in params:
            path_params['assetId'] = params['asset_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/assignments/asset/{assetId}/relationTypes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[RelationTypeImpl]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_assignment(self, assignment_id, **kwargs):  # noqa: E501
        """Removes the Assignment identified by the given id.  # noqa: E501

        Removes the Assignment identified by the given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_assignment(assignment_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assignment_id: The unique identifier of the Assignment. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_assignment_with_http_info(assignment_id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_assignment_with_http_info(assignment_id, **kwargs)  # noqa: E501
            return data

    def remove_assignment_with_http_info(self, assignment_id, **kwargs):  # noqa: E501
        """Removes the Assignment identified by the given id.  # noqa: E501

        Removes the Assignment identified by the given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_assignment_with_http_info(assignment_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assignment_id: The unique identifier of the Assignment. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['assignment_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_assignment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'assignment_id' is set
        if ('assignment_id' not in params or
                params['assignment_id'] is None):
            raise ValueError("Missing the required parameter `assignment_id` when calling `remove_assignment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'assignment_id' in params:
            path_params['assignmentId'] = params['assignment_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/assignments/{assignmentId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ChangeAttributeTypeRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'public_id': 'str',
        'name': 'str',
        'description': 'str',
        'language': 'str',
        'statistics_enabled': 'bool',
        'is_integer': 'bool',
        'allowed_values': 'list[str]'
    }

    attribute_map = {
        'id': 'id',
        'public_id': 'publicId',
        'name': 'name',
        'description': 'description',
        'language': 'language',
        'statistics_enabled': 'statisticsEnabled',
        'is_integer': 'isInteger',
        'allowed_values': 'allowedValues'
    }

    def __init__(self, id=None, public_id=None, name=None, description=None, language=None, statistics_enabled=None, is_integer=None, allowed_values=None):  # noqa: E501
        """ChangeAttributeTypeRequest - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._public_id = None
        self._name = None
        self._description = None
        self._language = None
        self._statistics_enabled = None
        self._is_integer = None
        self._allowed_values = None
        self.discriminator = None
        self.id = id
        if public_id is not None:
            self.public_id = public_id
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if language is not None:
            self.language = language
        if statistics_enabled is not None:
            self.statistics_enabled = statistics_enabled
        if is_integer is not None:
            self.is_integer = is_integer
        if allowed_values is not None:
            self.allowed_values = allowed_values

    @property
    def id(self):
        """Gets the id of this ChangeAttributeTypeRequest.  # noqa: E501

        The ID of the Attribute Type to be changed. Silently ignored if the ID is provided as path parameter of the request.  # noqa: E501

        :return: The id of this ChangeAttributeTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ChangeAttributeTypeRequest.

        The ID of the Attribute Type to be changed. Silently ignored if the ID is provided as path parameter of the request.  # noqa: E501

        :param id: The id of this ChangeAttributeTypeRequest.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def public_id(self):
        """Gets the public_id of this ChangeAttributeTypeRequest.  # noqa: E501

        The new public id for the Attribute Type. It must be unique within all Attribute Types. It should contain only ASCII letters and digits. It must start with an uppercase ASCII character. It must end with \"_C\". WARNING : The public id should only be changed with extreme caution, since it can break existing customizations. The only valid use case is to change it after creation of the type, if no public id was specified, and the generated proposal is not acceptable.  # noqa: E501

        :return: The public_id of this ChangeAttributeTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._public_id

    @public_id.setter
    def public_id(self, public_id):
        """Sets the public_id of this ChangeAttributeTypeRequest.

        The new public id for the Attribute Type. It must be unique within all Attribute Types. It should contain only ASCII letters and digits. It must start with an uppercase ASCII character. It must end with \"_C\". WARNING : The public id should only be changed with extreme caution, since it can break existing customizations. The only valid use case is to change it after creation of the type, if no public id was specified, and the generated proposal is not acceptable.  # noqa: E501

        :param public_id: The public_id of this ChangeAttributeTypeRequest.  # noqa: E501
        :type: str
        """

        self._public_id = public_id

    @property
    def name(self):
        """Gets the name of this ChangeAttributeTypeRequest.  # noqa: E501

        The new name for the Attribute Type.  # noqa: E501

        :return: The name of this ChangeAttributeTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ChangeAttributeTypeRequest.

        The new name for the Attribute Type.  # noqa: E501

        :param name: The name of this ChangeAttributeTypeRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this ChangeAttributeTypeRequest.  # noqa: E501

        The new description for the Attribute Type.  # noqa: E501

        :return: The description of this ChangeAttributeTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ChangeAttributeTypeRequest.

        The new description for the Attribute Type.  # noqa: E501

        :param description: The description of this ChangeAttributeTypeRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def language(self):
        """Gets the language of this ChangeAttributeTypeRequest.  # noqa: E501

        The new language for the Attribute Type. This property is only applicable to Attribute Types of kind \"Script\", and specifies the language of the script.  # noqa: E501

        :return: The language of this ChangeAttributeTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this ChangeAttributeTypeRequest.

        The new language for the Attribute Type. This property is only applicable to Attribute Types of kind \"Script\", and specifies the language of the script.  # noqa: E501

        :param language: The language of this ChangeAttributeTypeRequest.  # noqa: E501
        :type: str
        """

        self._language = language

    @property
    def statistics_enabled(self):
        """Gets the statistics_enabled of this ChangeAttributeTypeRequest.  # noqa: E501

        Whether statistics should be enabled. This property is only applicable to Attribute Types of kind \"Numeric\" or \"Boolean\".  # noqa: E501

        :return: The statistics_enabled of this ChangeAttributeTypeRequest.  # noqa: E501
        :rtype: bool
        """
        return self._statistics_enabled

    @statistics_enabled.setter
    def statistics_enabled(self, statistics_enabled):
        """Sets the statistics_enabled of this ChangeAttributeTypeRequest.

        Whether statistics should be enabled. This property is only applicable to Attribute Types of kind \"Numeric\" or \"Boolean\".  # noqa: E501

        :param statistics_enabled: The statistics_enabled of this ChangeAttributeTypeRequest.  # noqa: E501
        :type: bool
        """

        self._statistics_enabled = statistics_enabled

    @property
    def is_integer(self):
        """Gets the is_integer of this ChangeAttributeTypeRequest.  # noqa: E501

        Whether Attribute Type holds integer value. This property is only applicable to Attribute Types of kind \"Numeric\".  # noqa: E501

        :return: The is_integer of this ChangeAttributeTypeRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_integer

    @is_integer.setter
    def is_integer(self, is_integer):
        """Sets the is_integer of this ChangeAttributeTypeRequest.

        Whether Attribute Type holds integer value. This property is only applicable to Attribute Types of kind \"Numeric\".  # noqa: E501

        :param is_integer: The is_integer of this ChangeAttributeTypeRequest.  # noqa: E501
        :type: bool
        """

        self._is_integer = is_integer

    @property
    def allowed_values(self):
        """Gets the allowed_values of this ChangeAttributeTypeRequest.  # noqa: E501

        List of allowed values. This property is only applicable to Attribute Types of kind \"Single Value List\" or \"Multi Value List\".  # noqa: E501

        :return: The allowed_values of this ChangeAttributeTypeRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._allowed_values

    @allowed_values.setter
    def allowed_values(self, allowed_values):
        """Sets the allowed_values of this ChangeAttributeTypeRequest.

        List of allowed values. This property is only applicable to Attribute Types of kind \"Single Value List\" or \"Multi Value List\".  # noqa: E501

        :param allowed_values: The allowed_values of this ChangeAttributeTypeRequest.  # noqa: E501
        :type: list[str]
        """

        self._allowed_values = allowed_values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ChangeAttributeTypeRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChangeAttributeTypeRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient


class ActivitiesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_activities(self, **kwargs):  # noqa: E501
        """Returns activities matching the given search criteria.  # noqa: E501

        Returns activities matching the given search criteria.Only parameters that are specified in this request and have not <code>null</code> values are used for filtering.All other parameters are ignored.The returned activities satisfy all constraints that are specified in this search criteria.By default a result containing 100 activities is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activities(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Parameter not used in the context of activities, for performance reasons they are not counted.
        :param str task_id: The ID of the task which contains the basic find activities request.
        :param str context_id: The ID of the context which the activities should be searched for.
        :param list[str] involved_people_ids: The list of IDs of the people that should be involved in searched activities.
        :param list[str] involved_role_ids: The list of IDs of the roles that should be involved in searched activities.
        :param str performed_by_user_id: The ID of the user who performed searched activities.
        :param list[str] performed_by_role_ids: The list of IDs of the roles assigned to users who performed searched activities.
        :param str activity_type: The type of the activity.
        :param str call_id: The ID of the call.
        :param list[str] categories: The set of the categories of activities that should be searched. One of [ATTRIBUTE, ATTACHMENT, RELATION, COMMENT,<br/>STATUS, WORKFLOW, RESPONSIBILITY, USER, USER_GROUP, ROLE, TAGS, OTHERS].
        :param list[str] resource_types: The set of the resource types that searched activities refer to, i.e. [Community, Asset, Domain, Attribute,<br/>Relation, WorkflowInstance].
        :param int start_date: The start date of the searched activities, expressed as a Unix timestamp in milliseconds.
        :param int end_date: The end date of the searched activities, expressed as a Unix timestamp in milliseconds.
        :param bool call_count_enabled: Flag to indicate if the number of calls standing behind the activity should be returned or not.<br/>Note that by default that count will be not calculated as it brings an important performance penalty.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_activities_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_activities_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_activities_with_http_info(self, **kwargs):  # noqa: E501
        """Returns activities matching the given search criteria.  # noqa: E501

        Returns activities matching the given search criteria.Only parameters that are specified in this request and have not <code>null</code> values are used for filtering.All other parameters are ignored.The returned activities satisfy all constraints that are specified in this search criteria.By default a result containing 100 activities is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activities_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Parameter not used in the context of activities, for performance reasons they are not counted.
        :param str task_id: The ID of the task which contains the basic find activities request.
        :param str context_id: The ID of the context which the activities should be searched for.
        :param list[str] involved_people_ids: The list of IDs of the people that should be involved in searched activities.
        :param list[str] involved_role_ids: The list of IDs of the roles that should be involved in searched activities.
        :param str performed_by_user_id: The ID of the user who performed searched activities.
        :param list[str] performed_by_role_ids: The list of IDs of the roles assigned to users who performed searched activities.
        :param str activity_type: The type of the activity.
        :param str call_id: The ID of the call.
        :param list[str] categories: The set of the categories of activities that should be searched. One of [ATTRIBUTE, ATTACHMENT, RELATION, COMMENT,<br/>STATUS, WORKFLOW, RESPONSIBILITY, USER, USER_GROUP, ROLE, TAGS, OTHERS].
        :param list[str] resource_types: The set of the resource types that searched activities refer to, i.e. [Community, Asset, Domain, Attribute,<br/>Relation, WorkflowInstance].
        :param int start_date: The start date of the searched activities, expressed as a Unix timestamp in milliseconds.
        :param int end_date: The end date of the searched activities, expressed as a Unix timestamp in milliseconds.
        :param bool call_count_enabled: Flag to indicate if the number of calls standing behind the activity should be returned or not.<br/>Note that by default that count will be not calculated as it brings an important performance penalty.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['offset', 'limit', 'count_limit', 'task_id', 'context_id', 'involved_people_ids', 'involved_role_ids', 'performed_by_user_id', 'performed_by_role_ids', 'activity_type', 'call_id', 'categories', 'resource_types', 'start_date', 'end_date', 'call_count_enabled']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_activities" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'count_limit' in params:
            query_params.append(('countLimit', params['count_limit']))  # noqa: E501
        if 'task_id' in params:
            query_params.append(('taskId', params['task_id']))  # noqa: E501
        if 'context_id' in params:
            query_params.append(('contextId', params['context_id']))  # noqa: E501
        if 'involved_people_ids' in params:
            query_params.append(('involvedPeopleIds', params['involved_people_ids']))  # noqa: E501
            collection_formats['involvedPeopleIds'] = 'multi'  # noqa: E501
        if 'involved_role_ids' in params:
            query_params.append(('involvedRoleIds', params['involved_role_ids']))  # noqa: E501
            collection_formats['involvedRoleIds'] = 'multi'  # noqa: E501
        if 'performed_by_user_id' in params:
            query_params.append(('performedByUserId', params['performed_by_user_id']))  # noqa: E501
        if 'performed_by_role_ids' in params:
            query_params.append(('performedByRoleIds', params['performed_by_role_ids']))  # noqa: E501
            collection_formats['performedByRoleIds'] = 'multi'  # noqa: E501
        if 'activity_type' in params:
            query_params.append(('activityType', params['activity_type']))  # noqa: E501
        if 'call_id' in params:
            query_params.append(('callId', params['call_id']))  # noqa: E501
        if 'categories' in params:
            query_params.append(('categories', params['categories']))  # noqa: E501
            collection_formats['categories'] = 'multi'  # noqa: E501
        if 'resource_types' in params:
            query_params.append(('resourceTypes', params['resource_types']))  # noqa: E501
            collection_formats['resourceTypes'] = 'multi'  # noqa: E501
        if 'start_date' in params:
            query_params.append(('startDate', params['start_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('endDate', params['end_date']))  # noqa: E501
        if 'call_count_enabled' in params:
            query_params.append(('callCountEnabled', params['call_count_enabled']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/activities', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient


class DomainTypesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_domain_type(self, **kwargs):  # noqa: E501
        """Adds a new domain type.  # noqa: E501

        Adds a new domain type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_domain_type(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddDomainTypeRequest body:
        :return: DomainTypeImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_domain_type_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_domain_type_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_domain_type_with_http_info(self, **kwargs):  # noqa: E501
        """Adds a new domain type.  # noqa: E501

        Adds a new domain type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_domain_type_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddDomainTypeRequest body:
        :return: DomainTypeImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_domain_type" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/domainTypes', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DomainTypeImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_domain_types(self, **kwargs):  # noqa: E501
        """Adds multiple new domain types.  # noqa: E501

        Adds multiple new domain types.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_domain_types(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[AddDomainTypeRequest] body:
        :return: list[DomainTypeImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_domain_types_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_domain_types_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_domain_types_with_http_info(self, **kwargs):  # noqa: E501
        """Adds multiple new domain types.  # noqa: E501

        Adds multiple new domain types.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_domain_types_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[AddDomainTypeRequest] body:
        :return: list[DomainTypeImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_domain_types" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/domainTypes/bulk', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[DomainTypeImpl]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_domain_type(self, domain_type_id, **kwargs):  # noqa: E501
        """Changes the domain type.  # noqa: E501

        Changes the domain type with the information present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_domain_type(domain_type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str domain_type_id: the unique identifier of the domain type (required)
        :param ChangeDomainTypeRequest body:
        :return: DomainTypeImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_domain_type_with_http_info(domain_type_id, **kwargs)  # noqa: E501
        else:
            (data) = self.change_domain_type_with_http_info(domain_type_id, **kwargs)  # noqa: E501
            return data

    def change_domain_type_with_http_info(self, domain_type_id, **kwargs):  # noqa: E501
        """Changes the domain type.  # noqa: E501

        Changes the domain type with the information present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_domain_type_with_http_info(domain_type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str domain_type_id: the unique identifier of the domain type (required)
        :param ChangeDomainTypeRequest body:
        :return: DomainTypeImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['domain_type_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_domain_type" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'domain_type_id' is set
        if ('domain_type_id' not in params or
                params['domain_type_id'] is None):
            raise ValueError("Missing the required parameter `domain_type_id` when calling `change_domain_type`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'domain_type_id' in params:
            path_params['domainTypeId'] = params['domain_type_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/domainTypes/{domainTypeId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DomainTypeImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_domain_types(self, **kwargs):  # noqa: E501
        """Changes the domain types.  # noqa: E501

        Changes the domain types with the information present in the request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_domain_types(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[ChangeDomainTypeRequest] body:
        :return: list[DomainTypeImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_domain_types_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.change_domain_types_with_http_info(**kwargs)  # noqa: E501
            return data

    def change_domain_types_with_http_info(self, **kwargs):  # noqa: E501
        """Changes the domain types.  # noqa: E501

        Changes the domain types with the information present in the request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_domain_types_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[ChangeDomainTypeRequest] body:
        :return: list[DomainTypeImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_domain_types" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/domainTypes/bulk', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[DomainTypeImpl]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_domain_types(self, **kwargs):  # noqa: E501
        """Returns domain types matching the given search criteria.  # noqa: E501

        Returns domain types matching the given search criteria. Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored. The returned domain types satisfy all constraints that are specified in this search criteria. By default a result containing 1000 domain types is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_domain_types(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str name: The name of the Domain Type to search for.
        :param str name_match_mode: The match mode used to compare <code>name</code>. The search is case-insensitive.
        :param str parent_id: The ID of the parent to find the Domain Types in.
        :param bool exclude_meta: Whether the meta Domain Types should be excluded from search or not.
        :param bool top_level: Whether only top level Domain Types should be searched or not.
        :return: DomainTypePagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_domain_types_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.find_domain_types_with_http_info(**kwargs)  # noqa: E501
            return data

    def find_domain_types_with_http_info(self, **kwargs):  # noqa: E501
        """Returns domain types matching the given search criteria.  # noqa: E501

        Returns domain types matching the given search criteria. Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored. The returned domain types satisfy all constraints that are specified in this search criteria. By default a result containing 1000 domain types is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_domain_types_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str name: The name of the Domain Type to search for.
        :param str name_match_mode: The match mode used to compare <code>name</code>. The search is case-insensitive.
        :param str parent_id: The ID of the parent to find the Domain Types in.
        :param bool exclude_meta: Whether the meta Domain Types should be excluded from search or not.
        :param bool top_level: Whether only top level Domain Types should be searched or not.
        :return: DomainTypePagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['offset', 'limit', 'count_limit', 'name', 'name_match_mode', 'parent_id', 'exclude_meta', 'top_level']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_domain_types" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'count_limit' in params:
            query_params.append(('countLimit', params['count_limit']))  # noqa: E501
        if 'name' in params:
            query_params.append(('name', params['name']))  # noqa: E501
        if 'name_match_mode' in params:
            query_params.append(('nameMatchMode', params['name_match_mode']))  # noqa: E501
        if 'parent_id' in params:
            query_params.append(('parentId', params['parent_id']))  # noqa: E501
        if 'exclude_meta' in params:
            query_params.append(('excludeMeta', params['exclude_meta']))  # noqa: E501
        if 'top_level' in params:
            query_params.append(('topLevel', params['top_level']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/domainTypes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DomainTypePagedResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_sub_domain_types(self, domain_type_id, **kwargs):  # noqa: E501
        """Returns sub domain types matching the given search criteria.  # noqa: E501

        Returns sub domain types matching the given search criteria.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_sub_domain_types(domain_type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str domain_type_id: the unique identifier of the domain type (required)
        :param str domain_type_id: The ID of the Domain Type to search the subtypes of. Because it duplicates the corresponding domainTypeId path parameter and prevents some client code generators from working as expected, this will be removed in the next quarterly release. (required)
        :param bool include_parent: Whether parent Domain Type should be included in the search result.
        :return: DomainTypePagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_sub_domain_types_with_http_info(domain_type_id,  **kwargs)  # noqa: E501
        else:
            (data) = self.find_sub_domain_types_with_http_info(domain_type_id,  **kwargs)  # noqa: E501
            return data

    def find_sub_domain_types_with_http_info(self, domain_type_id,  **kwargs):  # noqa: E501
        """Returns sub domain types matching the given search criteria.  # noqa: E501

        Returns sub domain types matching the given search criteria.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_sub_domain_types_with_http_info(domain_type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str domain_type_id: the unique identifier of the domain type (required)
        :param str domain_type_id: The ID of the Domain Type to search the subtypes of. Because it duplicates the corresponding domainTypeId path parameter and prevents some client code generators from working as expected, this will be removed in the next quarterly release. (required)
        :param bool include_parent: Whether parent Domain Type should be included in the search result.
        :return: DomainTypePagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['domain_type_id', 'domain_type_id', 'include_parent']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_sub_domain_types" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'domain_type_id' is set
        if ('domain_type_id' not in params or
                params['domain_type_id'] is None):
            raise ValueError("Missing the required parameter `domain_type_id` when calling `find_sub_domain_types`")  # noqa: E501
        # verify the required parameter 'domain_type_id' is set
        if ('domain_type_id' not in params or
                params['domain_type_id'] is None):
            raise ValueError("Missing the required parameter `domain_type_id` when calling `find_sub_domain_types`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'domain_type_id' in params:
            path_params['domainTypeId'] = params['domain_type_id']  # noqa: E501

        query_params = []
        if 'domain_type_id' in params:
            query_params.append(('domainTypeId', params['domain_type_id']))  # noqa: E501
        if 'include_parent' in params:
            query_params.append(('includeParent', params['include_parent']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/domainTypes/{domainTypeId}/subTypes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DomainTypePagedResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_domain_type(self, domain_type_id, **kwargs):  # noqa: E501
        """Returns domain type identified by given UUID.  # noqa: E501

        Returns domain type identified by given UUID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_domain_type(domain_type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str domain_type_id: the unique identifier of the domain type (required)
        :return: DomainTypeImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_domain_type_with_http_info(domain_type_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_domain_type_with_http_info(domain_type_id, **kwargs)  # noqa: E501
            return data

    def get_domain_type_with_http_info(self, domain_type_id, **kwargs):  # noqa: E501
        """Returns domain type identified by given UUID.  # noqa: E501

        Returns domain type identified by given UUID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_domain_type_with_http_info(domain_type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str domain_type_id: the unique identifier of the domain type (required)
        :return: DomainTypeImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['domain_type_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_domain_type" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'domain_type_id' is set
        if ('domain_type_id' not in params or
                params['domain_type_id'] is None):
            raise ValueError("Missing the required parameter `domain_type_id` when calling `get_domain_type`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'domain_type_id' in params:
            path_params['domainTypeId'] = params['domain_type_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/domainTypes/{domainTypeId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DomainTypeImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_domain_type(self, domain_type_id, **kwargs):  # noqa: E501
        """Removes domain type identified by given UUID.  # noqa: E501

        Removes domain type identified by given UUID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_domain_type(domain_type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str domain_type_id: the unique identifier of the domain type (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_domain_type_with_http_info(domain_type_id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_domain_type_with_http_info(domain_type_id, **kwargs)  # noqa: E501
            return data

    def remove_domain_type_with_http_info(self, domain_type_id, **kwargs):  # noqa: E501
        """Removes domain type identified by given UUID.  # noqa: E501

        Removes domain type identified by given UUID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_domain_type_with_http_info(domain_type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str domain_type_id: the unique identifier of the domain type (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['domain_type_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_domain_type" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'domain_type_id' is set
        if ('domain_type_id' not in params or
                params['domain_type_id'] is None):
            raise ValueError("Missing the required parameter `domain_type_id` when calling `remove_domain_type`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'domain_type_id' in params:
            path_params['domainTypeId'] = params['domain_type_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/domainTypes/{domainTypeId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_domain_types(self, **kwargs):  # noqa: E501
        """Removes multiple domain types.  # noqa: E501

        Removes multiple domain types identified by the UUIDs passed as parameter.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_domain_types(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_domain_types_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.remove_domain_types_with_http_info(**kwargs)  # noqa: E501
            return data

    def remove_domain_types_with_http_info(self, **kwargs):  # noqa: E501
        """Removes multiple domain types.  # noqa: E501

        Removes multiple domain types identified by the UUIDs passed as parameter.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_domain_types_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_domain_types" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/domainTypes/bulk', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class StartWorkflowInstancesRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'workflow_definition_id': 'str',
        'business_item_ids': 'list[str]',
        'business_item_type': 'str',
        'form_properties': 'dict(str, str)',
        'guest_user_id': 'str',
        'send_notification': 'bool'
    }

    attribute_map = {
        'workflow_definition_id': 'workflowDefinitionId',
        'business_item_ids': 'businessItemIds',
        'business_item_type': 'businessItemType',
        'form_properties': 'formProperties',
        'guest_user_id': 'guestUserId',
        'send_notification': 'sendNotification'
    }

    def __init__(self, workflow_definition_id=None, business_item_ids=None, business_item_type=None, form_properties=None, guest_user_id=None, send_notification=None):  # noqa: E501
        """StartWorkflowInstancesRequest - a model defined in Swagger"""  # noqa: E501
        self._workflow_definition_id = None
        self._business_item_ids = None
        self._business_item_type = None
        self._form_properties = None
        self._guest_user_id = None
        self._send_notification = None
        self.discriminator = None
        self.workflow_definition_id = workflow_definition_id
        if business_item_ids is not None:
            self.business_item_ids = business_item_ids
        if business_item_type is not None:
            self.business_item_type = business_item_type
        if form_properties is not None:
            self.form_properties = form_properties
        if guest_user_id is not None:
            self.guest_user_id = guest_user_id
        if send_notification is not None:
            self.send_notification = send_notification

    @property
    def workflow_definition_id(self):
        """Gets the workflow_definition_id of this StartWorkflowInstancesRequest.  # noqa: E501

        The ID of the workflow definition.  # noqa: E501

        :return: The workflow_definition_id of this StartWorkflowInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._workflow_definition_id

    @workflow_definition_id.setter
    def workflow_definition_id(self, workflow_definition_id):
        """Sets the workflow_definition_id of this StartWorkflowInstancesRequest.

        The ID of the workflow definition.  # noqa: E501

        :param workflow_definition_id: The workflow_definition_id of this StartWorkflowInstancesRequest.  # noqa: E501
        :type: str
        """
        if workflow_definition_id is None:
            raise ValueError("Invalid value for `workflow_definition_id`, must not be `None`")  # noqa: E501

        self._workflow_definition_id = workflow_definition_id

    @property
    def business_item_ids(self):
        """Gets the business_item_ids of this StartWorkflowInstancesRequest.  # noqa: E501

        The list of IDs for the business items.  # noqa: E501

        :return: The business_item_ids of this StartWorkflowInstancesRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._business_item_ids

    @business_item_ids.setter
    def business_item_ids(self, business_item_ids):
        """Sets the business_item_ids of this StartWorkflowInstancesRequest.

        The list of IDs for the business items.  # noqa: E501

        :param business_item_ids: The business_item_ids of this StartWorkflowInstancesRequest.  # noqa: E501
        :type: list[str]
        """

        self._business_item_ids = business_item_ids

    @property
    def business_item_type(self):
        """Gets the business_item_type of this StartWorkflowInstancesRequest.  # noqa: E501

        The resource type of the passed in business items.  # noqa: E501

        :return: The business_item_type of this StartWorkflowInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_item_type

    @business_item_type.setter
    def business_item_type(self, business_item_type):
        """Sets the business_item_type of this StartWorkflowInstancesRequest.

        The resource type of the passed in business items.  # noqa: E501

        :param business_item_type: The business_item_type of this StartWorkflowInstancesRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["ASSET", "DOMAIN", "COMMUNITY", "GLOBAL"]  # noqa: E501
        if business_item_type not in allowed_values:
            raise ValueError(
                "Invalid value for `business_item_type` ({0}), must be one of {1}"  # noqa: E501
                .format(business_item_type, allowed_values)
            )

        self._business_item_type = business_item_type

    @property
    def form_properties(self):
        """Gets the form_properties of this StartWorkflowInstancesRequest.  # noqa: E501

        The properties of the workflow.  # noqa: E501

        :return: The form_properties of this StartWorkflowInstancesRequest.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._form_properties

    @form_properties.setter
    def form_properties(self, form_properties):
        """Sets the form_properties of this StartWorkflowInstancesRequest.

        The properties of the workflow.  # noqa: E501

        :param form_properties: The form_properties of this StartWorkflowInstancesRequest.  # noqa: E501
        :type: dict(str, str)
        """

        self._form_properties = form_properties

    @property
    def guest_user_id(self):
        """Gets the guest_user_id of this StartWorkflowInstancesRequest.  # noqa: E501

        The ID of the guest user starting the workflow.  # noqa: E501

        :return: The guest_user_id of this StartWorkflowInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._guest_user_id

    @guest_user_id.setter
    def guest_user_id(self, guest_user_id):
        """Sets the guest_user_id of this StartWorkflowInstancesRequest.

        The ID of the guest user starting the workflow.  # noqa: E501

        :param guest_user_id: The guest_user_id of this StartWorkflowInstancesRequest.  # noqa: E501
        :type: str
        """

        self._guest_user_id = guest_user_id

    @property
    def send_notification(self):
        """Gets the send_notification of this StartWorkflowInstancesRequest.  # noqa: E501

        Whether a mail notification on starting the workflows should be sent. This notification is only used in the asynchronous api version (in a job).  # noqa: E501

        :return: The send_notification of this StartWorkflowInstancesRequest.  # noqa: E501
        :rtype: bool
        """
        return self._send_notification

    @send_notification.setter
    def send_notification(self, send_notification):
        """Sets the send_notification of this StartWorkflowInstancesRequest.

        Whether a mail notification on starting the workflows should be sent. This notification is only used in the asynchronous api version (in a job).  # noqa: E501

        :param send_notification: The send_notification of this StartWorkflowInstancesRequest.  # noqa: E501
        :type: bool
        """

        self._send_notification = send_notification

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StartWorkflowInstancesRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StartWorkflowInstancesRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ComplexRelationLegTypeImpl(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'created_by': 'str',
        'created_on': 'int',
        'last_modified_by': 'str',
        'last_modified_on': 'int',
        'system': 'bool',
        'resource_type': 'str',
        'minimum_occurrences': 'int',
        'maximum_occurrences': 'int',
        'asset_type': 'NamedResourceReferenceImpl',
        'role': 'str',
        'co_role': 'str',
        'relation_type_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'created_by': 'createdBy',
        'created_on': 'createdOn',
        'last_modified_by': 'lastModifiedBy',
        'last_modified_on': 'lastModifiedOn',
        'system': 'system',
        'resource_type': 'resourceType',
        'minimum_occurrences': 'minimumOccurrences',
        'maximum_occurrences': 'maximumOccurrences',
        'asset_type': 'assetType',
        'role': 'role',
        'co_role': 'coRole',
        'relation_type_id': 'relationTypeId'
    }

    def __init__(self, id=None, created_by=None, created_on=None, last_modified_by=None, last_modified_on=None, system=None, resource_type=None, minimum_occurrences=None, maximum_occurrences=None, asset_type=None, role=None, co_role=None, relation_type_id=None):  # noqa: E501
        """ComplexRelationLegTypeImpl - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._created_by = None
        self._created_on = None
        self._last_modified_by = None
        self._last_modified_on = None
        self._system = None
        self._resource_type = None
        self._minimum_occurrences = None
        self._maximum_occurrences = None
        self._asset_type = None
        self._role = None
        self._co_role = None
        self._relation_type_id = None
        self.discriminator = None
        self.id = id
        if created_by is not None:
            self.created_by = created_by
        if created_on is not None:
            self.created_on = created_on
        if last_modified_by is not None:
            self.last_modified_by = last_modified_by
        if last_modified_on is not None:
            self.last_modified_on = last_modified_on
        if system is not None:
            self.system = system
        self.resource_type = resource_type
        if minimum_occurrences is not None:
            self.minimum_occurrences = minimum_occurrences
        if maximum_occurrences is not None:
            self.maximum_occurrences = maximum_occurrences
        if asset_type is not None:
            self.asset_type = asset_type
        if role is not None:
            self.role = role
        if co_role is not None:
            self.co_role = co_role
        if relation_type_id is not None:
            self.relation_type_id = relation_type_id

    @property
    def id(self):
        """Gets the id of this ComplexRelationLegTypeImpl.  # noqa: E501

        The id of the represented object (entity).  # noqa: E501

        :return: The id of this ComplexRelationLegTypeImpl.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ComplexRelationLegTypeImpl.

        The id of the represented object (entity).  # noqa: E501

        :param id: The id of this ComplexRelationLegTypeImpl.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def created_by(self):
        """Gets the created_by of this ComplexRelationLegTypeImpl.  # noqa: E501

        The id of the user that created this resource.  # noqa: E501

        :return: The created_by of this ComplexRelationLegTypeImpl.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this ComplexRelationLegTypeImpl.

        The id of the user that created this resource.  # noqa: E501

        :param created_by: The created_by of this ComplexRelationLegTypeImpl.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def created_on(self):
        """Gets the created_on of this ComplexRelationLegTypeImpl.  # noqa: E501

        The timestamp (in UTC time standard) of the creation of this resource.  # noqa: E501

        :return: The created_on of this ComplexRelationLegTypeImpl.  # noqa: E501
        :rtype: int
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this ComplexRelationLegTypeImpl.

        The timestamp (in UTC time standard) of the creation of this resource.  # noqa: E501

        :param created_on: The created_on of this ComplexRelationLegTypeImpl.  # noqa: E501
        :type: int
        """

        self._created_on = created_on

    @property
    def last_modified_by(self):
        """Gets the last_modified_by of this ComplexRelationLegTypeImpl.  # noqa: E501

        The id of the user who modified this resource the last time.  # noqa: E501

        :return: The last_modified_by of this ComplexRelationLegTypeImpl.  # noqa: E501
        :rtype: str
        """
        return self._last_modified_by

    @last_modified_by.setter
    def last_modified_by(self, last_modified_by):
        """Sets the last_modified_by of this ComplexRelationLegTypeImpl.

        The id of the user who modified this resource the last time.  # noqa: E501

        :param last_modified_by: The last_modified_by of this ComplexRelationLegTypeImpl.  # noqa: E501
        :type: str
        """

        self._last_modified_by = last_modified_by

    @property
    def last_modified_on(self):
        """Gets the last_modified_on of this ComplexRelationLegTypeImpl.  # noqa: E501

        The timestamp (in UTC time standard) of the last modification of this resource.  # noqa: E501

        :return: The last_modified_on of this ComplexRelationLegTypeImpl.  # noqa: E501
        :rtype: int
        """
        return self._last_modified_on

    @last_modified_on.setter
    def last_modified_on(self, last_modified_on):
        """Sets the last_modified_on of this ComplexRelationLegTypeImpl.

        The timestamp (in UTC time standard) of the last modification of this resource.  # noqa: E501

        :param last_modified_on: The last_modified_on of this ComplexRelationLegTypeImpl.  # noqa: E501
        :type: int
        """

        self._last_modified_on = last_modified_on

    @property
    def system(self):
        """Gets the system of this ComplexRelationLegTypeImpl.  # noqa: E501

        Whether this is a system resource or not.  # noqa: E501

        :return: The system of this ComplexRelationLegTypeImpl.  # noqa: E501
        :rtype: bool
        """
        return self._system

    @system.setter
    def system(self, system):
        """Sets the system of this ComplexRelationLegTypeImpl.

        Whether this is a system resource or not.  # noqa: E501

        :param system: The system of this ComplexRelationLegTypeImpl.  # noqa: E501
        :type: bool
        """

        self._system = system

    @property
    def resource_type(self):
        """Gets the resource_type of this ComplexRelationLegTypeImpl.  # noqa: E501

        The type of this resource, i.e. [Community, Asset, Domain, Attribute, Relation, WorkflowInstance].  # noqa: E501

        :return: The resource_type of this ComplexRelationLegTypeImpl.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this ComplexRelationLegTypeImpl.

        The type of this resource, i.e. [Community, Asset, Domain, Attribute, Relation, WorkflowInstance].  # noqa: E501

        :param resource_type: The resource_type of this ComplexRelationLegTypeImpl.  # noqa: E501
        :type: str
        """
        if resource_type is None:
            raise ValueError("Invalid value for `resource_type`, must not be `None`")  # noqa: E501
        allowed_values = ["View", "Asset", "Community", "Domain", "AssetType", "DomainType", "Status", "User", "ClassificationMatch", "UserGroup", "Attribute", "StringAttribute", "ScriptAttribute", "BooleanAttribute", "DateAttribute", "NumericAttribute", "SingleValueListAttribute", "MultiValueListAttribute", "Comment", "Attachment", "Responsibility", "Workflow", "Job", "Relation", "RelationType", "ComplexRelation", "ComplexRelationType", "ArticulationRule", "Assignment", "Scope", "RelationTrace", "ValidationRule", "DataQualityRule", "DataQualityMetric", "Address", "InstantMessagingAccount", "Email", "PhoneNumber", "Website", "Activity", "FormProperty", "WorkflowTask", "ActivityChange", "WorkflowInstance", "Role", "AttributeType", "BooleanAttributeType", "DateAttributeType", "DateTimeAttributeType", "MultiValueListAttributeType", "NumericAttributeType", "ScriptAttributeType", "SingleValueListAttributeType", "StringAttributeType", "ViewSharingRule", "ViewAssignmentRule", "JdbcDriverFile", "JdbcDriver", "JdbcIngestionProperties", "CsvIngestionProperties", "ExcelIngestionProperties", "ConnectionStringParameter", "AssignedCharacteristicType", "Notification", "Tag", "ComplexRelationLegType", "ComplexRelationAttributeType", "ComplexRelationLeg", "BaseDataType", "AdvancedDataType", "DiagramPicture", "DiagramPictureSharingRule", "DiagramPictureAssignmentRule", "Rating", "Classification", "PhysicalDataConnector", "Context"]  # noqa: E501
        if resource_type not in allowed_values:
            raise ValueError(
                "Invalid value for `resource_type` ({0}), must be one of {1}"  # noqa: E501
                .format(resource_type, allowed_values)
            )

        self._resource_type = resource_type

    @property
    def minimum_occurrences(self):
        """Gets the minimum_occurrences of this ComplexRelationLegTypeImpl.  # noqa: E501


        :return: The minimum_occurrences of this ComplexRelationLegTypeImpl.  # noqa: E501
        :rtype: int
        """
        return self._minimum_occurrences

    @minimum_occurrences.setter
    def minimum_occurrences(self, minimum_occurrences):
        """Sets the minimum_occurrences of this ComplexRelationLegTypeImpl.


        :param minimum_occurrences: The minimum_occurrences of this ComplexRelationLegTypeImpl.  # noqa: E501
        :type: int
        """

        self._minimum_occurrences = minimum_occurrences

    @property
    def maximum_occurrences(self):
        """Gets the maximum_occurrences of this ComplexRelationLegTypeImpl.  # noqa: E501


        :return: The maximum_occurrences of this ComplexRelationLegTypeImpl.  # noqa: E501
        :rtype: int
        """
        return self._maximum_occurrences

    @maximum_occurrences.setter
    def maximum_occurrences(self, maximum_occurrences):
        """Sets the maximum_occurrences of this ComplexRelationLegTypeImpl.


        :param maximum_occurrences: The maximum_occurrences of this ComplexRelationLegTypeImpl.  # noqa: E501
        :type: int
        """

        self._maximum_occurrences = maximum_occurrences

    @property
    def asset_type(self):
        """Gets the asset_type of this ComplexRelationLegTypeImpl.  # noqa: E501


        :return: The asset_type of this ComplexRelationLegTypeImpl.  # noqa: E501
        :rtype: NamedResourceReferenceImpl
        """
        return self._asset_type

    @asset_type.setter
    def asset_type(self, asset_type):
        """Sets the asset_type of this ComplexRelationLegTypeImpl.


        :param asset_type: The asset_type of this ComplexRelationLegTypeImpl.  # noqa: E501
        :type: NamedResourceReferenceImpl
        """

        self._asset_type = asset_type

    @property
    def role(self):
        """Gets the role of this ComplexRelationLegTypeImpl.  # noqa: E501


        :return: The role of this ComplexRelationLegTypeImpl.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this ComplexRelationLegTypeImpl.


        :param role: The role of this ComplexRelationLegTypeImpl.  # noqa: E501
        :type: str
        """

        self._role = role

    @property
    def co_role(self):
        """Gets the co_role of this ComplexRelationLegTypeImpl.  # noqa: E501


        :return: The co_role of this ComplexRelationLegTypeImpl.  # noqa: E501
        :rtype: str
        """
        return self._co_role

    @co_role.setter
    def co_role(self, co_role):
        """Sets the co_role of this ComplexRelationLegTypeImpl.


        :param co_role: The co_role of this ComplexRelationLegTypeImpl.  # noqa: E501
        :type: str
        """

        self._co_role = co_role

    @property
    def relation_type_id(self):
        """Gets the relation_type_id of this ComplexRelationLegTypeImpl.  # noqa: E501


        :return: The relation_type_id of this ComplexRelationLegTypeImpl.  # noqa: E501
        :rtype: str
        """
        return self._relation_type_id

    @relation_type_id.setter
    def relation_type_id(self, relation_type_id):
        """Sets the relation_type_id of this ComplexRelationLegTypeImpl.


        :param relation_type_id: The relation_type_id of this ComplexRelationLegTypeImpl.  # noqa: E501
        :type: str
        """

        self._relation_type_id = relation_type_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ComplexRelationLegTypeImpl, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ComplexRelationLegTypeImpl):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient


class NavigationStatisticsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def find_most_viewed_assets(self, **kwargs):  # noqa: E501
        """Find most viewed assets.  # noqa: E501

        Returns the most viewed assets by all users, with navigation-related info.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_most_viewed_assets(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param int period: The time span for which most viewed assets should be found. This time span must be expressed in milliseconds.<br/>For instance, to get most viewed assets for last 24 hours, period would be <code>86400000</code>.<br/>If it's unset (period = 0) looks for all time most viewed assets.
        :param bool is_guest_excluded: Whether guest visits should be excluded from result.
        :return: NavigationStatisticsEntryPagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_most_viewed_assets_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.find_most_viewed_assets_with_http_info(**kwargs)  # noqa: E501
            return data

    def find_most_viewed_assets_with_http_info(self, **kwargs):  # noqa: E501
        """Find most viewed assets.  # noqa: E501

        Returns the most viewed assets by all users, with navigation-related info.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_most_viewed_assets_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param int period: The time span for which most viewed assets should be found. This time span must be expressed in milliseconds.<br/>For instance, to get most viewed assets for last 24 hours, period would be <code>86400000</code>.<br/>If it's unset (period = 0) looks for all time most viewed assets.
        :param bool is_guest_excluded: Whether guest visits should be excluded from result.
        :return: NavigationStatisticsEntryPagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['offset', 'limit', 'count_limit', 'period', 'is_guest_excluded']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_most_viewed_assets" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'count_limit' in params:
            query_params.append(('countLimit', params['count_limit']))  # noqa: E501
        if 'period' in params:
            query_params.append(('period', params['period']))  # noqa: E501
        if 'is_guest_excluded' in params:
            query_params.append(('isGuestExcluded', params['is_guest_excluded']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/navigation/most_viewed', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='NavigationStatisticsEntryPagedResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_recently_viewed_assets(self, **kwargs):  # noqa: E501
        """Find recently viewed assets.  # noqa: E501

        Returns the assets that were recently viewed by the current user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_recently_viewed_assets(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :return: NavigationStatisticsEntryPagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_recently_viewed_assets_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.find_recently_viewed_assets_with_http_info(**kwargs)  # noqa: E501
            return data

    def find_recently_viewed_assets_with_http_info(self, **kwargs):  # noqa: E501
        """Find recently viewed assets.  # noqa: E501

        Returns the assets that were recently viewed by the current user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_recently_viewed_assets_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :return: NavigationStatisticsEntryPagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['offset', 'limit', 'count_limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_recently_viewed_assets" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'count_limit' in params:
            query_params.append(('countLimit', params['count_limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/navigation/recently_viewed', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='NavigationStatisticsEntryPagedResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient


class RelationTypesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_relation_type(self, **kwargs):  # noqa: E501
        """Adds a new relation type.  # noqa: E501

        Adds a new relation type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_relation_type(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddRelationTypeRequest body:
        :return: RelationTypeImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_relation_type_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_relation_type_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_relation_type_with_http_info(self, **kwargs):  # noqa: E501
        """Adds a new relation type.  # noqa: E501

        Adds a new relation type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_relation_type_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddRelationTypeRequest body:
        :return: RelationTypeImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_relation_type" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/relationTypes', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RelationTypeImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_relation_types(self, **kwargs):  # noqa: E501
        """Adds multiple new relation type.  # noqa: E501

        Adds multiple new relation type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_relation_types(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[AddRelationTypeRequest] body:
        :return: list[RelationTypeImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_relation_types_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_relation_types_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_relation_types_with_http_info(self, **kwargs):  # noqa: E501
        """Adds multiple new relation type.  # noqa: E501

        Adds multiple new relation type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_relation_types_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[AddRelationTypeRequest] body:
        :return: list[RelationTypeImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_relation_types" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/relationTypes/bulk', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[RelationTypeImpl]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_relation_type(self, relation_type_id, **kwargs):  # noqa: E501
        """Changes the relation type.  # noqa: E501

        Changes the relation type with the information that is present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_relation_type(relation_type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str relation_type_id: The unique identifier of the relationType (required)
        :param ChangeRelationTypeRequest body:
        :return: RelationTypeImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_relation_type_with_http_info(relation_type_id, **kwargs)  # noqa: E501
        else:
            (data) = self.change_relation_type_with_http_info(relation_type_id, **kwargs)  # noqa: E501
            return data

    def change_relation_type_with_http_info(self, relation_type_id, **kwargs):  # noqa: E501
        """Changes the relation type.  # noqa: E501

        Changes the relation type with the information that is present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_relation_type_with_http_info(relation_type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str relation_type_id: The unique identifier of the relationType (required)
        :param ChangeRelationTypeRequest body:
        :return: RelationTypeImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['relation_type_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_relation_type" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'relation_type_id' is set
        if ('relation_type_id' not in params or
                params['relation_type_id'] is None):
            raise ValueError("Missing the required parameter `relation_type_id` when calling `change_relation_type`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'relation_type_id' in params:
            path_params['relationTypeId'] = params['relation_type_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/relationTypes/{relationTypeId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RelationTypeImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_relation_types(self, **kwargs):  # noqa: E501
        """Changes the relation types.  # noqa: E501

        Changes the relation types with the information that is present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_relation_types(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[ChangeRelationTypeRequest] body:
        :return: list[RelationTypeImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_relation_types_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.change_relation_types_with_http_info(**kwargs)  # noqa: E501
            return data

    def change_relation_types_with_http_info(self, **kwargs):  # noqa: E501
        """Changes the relation types.  # noqa: E501

        Changes the relation types with the information that is present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_relation_types_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[ChangeRelationTypeRequest] body:
        :return: list[RelationTypeImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_relation_types" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/relationTypes/bulk', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[RelationTypeImpl]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_relation_types(self, **kwargs):  # noqa: E501
        """Finds all the relation types matching the given criteria.  # noqa: E501

        Returns relation types matching the given search criteria. Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored. The returned relation types satisfy all constraints that are specified in this search criteria. By default a result containing 1000 relation types is returned.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_relation_types(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str source_type_id: The ID of the source type of the Relation Type to search for.
        :param str source_type_name: The name of the source type of the Relation Type to search for.
        :param str role: The name of the role that the source plays to search for.
        :param str target_type_id: The ID of the target type of the Relation Type to search for.
        :param str target_type_name: The name of the target type of the Relation Type to search for.
        :param str co_role: The name of the role that the target plays to search for.
        :param str sort_field: The field that should be used as reference for sorting.
        :param str sort_order: The order of sorting.
        :param str role_co_role_logical_operator: The logical operator determining how to combine the role and coRole criteria: AND or OR.
        :return: RelationTypePagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_relation_types_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.find_relation_types_with_http_info(**kwargs)  # noqa: E501
            return data

    def find_relation_types_with_http_info(self, **kwargs):  # noqa: E501
        """Finds all the relation types matching the given criteria.  # noqa: E501

        Returns relation types matching the given search criteria. Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored. The returned relation types satisfy all constraints that are specified in this search criteria. By default a result containing 1000 relation types is returned.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_relation_types_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str source_type_id: The ID of the source type of the Relation Type to search for.
        :param str source_type_name: The name of the source type of the Relation Type to search for.
        :param str role: The name of the role that the source plays to search for.
        :param str target_type_id: The ID of the target type of the Relation Type to search for.
        :param str target_type_name: The name of the target type of the Relation Type to search for.
        :param str co_role: The name of the role that the target plays to search for.
        :param str sort_field: The field that should be used as reference for sorting.
        :param str sort_order: The order of sorting.
        :param str role_co_role_logical_operator: The logical operator determining how to combine the role and coRole criteria: AND or OR.
        :return: RelationTypePagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['offset', 'limit', 'count_limit', 'source_type_id', 'source_type_name', 'role', 'target_type_id', 'target_type_name', 'co_role', 'sort_field', 'sort_order', 'role_co_role_logical_operator']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_relation_types" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'count_limit' in params:
            query_params.append(('countLimit', params['count_limit']))  # noqa: E501
        if 'source_type_id' in params:
            query_params.append(('sourceTypeId', params['source_type_id']))  # noqa: E501
        if 'source_type_name' in params:
            query_params.append(('sourceTypeName', params['source_type_name']))  # noqa: E501
        if 'role' in params:
            query_params.append(('role', params['role']))  # noqa: E501
        if 'target_type_id' in params:
            query_params.append(('targetTypeId', params['target_type_id']))  # noqa: E501
        if 'target_type_name' in params:
            query_params.append(('targetTypeName', params['target_type_name']))  # noqa: E501
        if 'co_role' in params:
            query_params.append(('coRole', params['co_role']))  # noqa: E501
        if 'sort_field' in params:
            query_params.append(('sortField', params['sort_field']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('sortOrder', params['sort_order']))  # noqa: E501
        if 'role_co_role_logical_operator' in params:
            query_params.append(('roleCoRoleLogicalOperator', params['role_co_role_logical_operator']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/relationTypes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RelationTypePagedResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_relation_type(self, relation_type_id, **kwargs):  # noqa: E501
        """Returns relation type identified by given UUID.  # noqa: E501

        Returns relation type identified by given UUID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_relation_type(relation_type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str relation_type_id: The unique identifier of the relationType (required)
        :return: RelationTypeImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_relation_type_with_http_info(relation_type_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_relation_type_with_http_info(relation_type_id, **kwargs)  # noqa: E501
            return data

    def get_relation_type_with_http_info(self, relation_type_id, **kwargs):  # noqa: E501
        """Returns relation type identified by given UUID.  # noqa: E501

        Returns relation type identified by given UUID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_relation_type_with_http_info(relation_type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str relation_type_id: The unique identifier of the relationType (required)
        :return: RelationTypeImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['relation_type_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_relation_type" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'relation_type_id' is set
        if ('relation_type_id' not in params or
                params['relation_type_id'] is None):
            raise ValueError("Missing the required parameter `relation_type_id` when calling `get_relation_type`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'relation_type_id' in params:
            path_params['relationTypeId'] = params['relation_type_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/relationTypes/{relationTypeId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RelationTypeImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_relation_type(self, relation_type_id, **kwargs):  # noqa: E501
        """Removes relation type identified by given UUID.  # noqa: E501

        Removes relation type identified by given UUID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_relation_type(relation_type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str relation_type_id: The unique identifier of the relationType (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_relation_type_with_http_info(relation_type_id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_relation_type_with_http_info(relation_type_id, **kwargs)  # noqa: E501
            return data

    def remove_relation_type_with_http_info(self, relation_type_id, **kwargs):  # noqa: E501
        """Removes relation type identified by given UUID.  # noqa: E501

        Removes relation type identified by given UUID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_relation_type_with_http_info(relation_type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str relation_type_id: The unique identifier of the relationType (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['relation_type_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_relation_type" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'relation_type_id' is set
        if ('relation_type_id' not in params or
                params['relation_type_id'] is None):
            raise ValueError("Missing the required parameter `relation_type_id` when calling `remove_relation_type`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'relation_type_id' in params:
            path_params['relationTypeId'] = params['relation_type_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/relationTypes/{relationTypeId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_relation_types(self, **kwargs):  # noqa: E501
        """Removes multiple relation types.  # noqa: E501

        Removes multiple relation types identified by the UUIDs passed as parameter.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_relation_types(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] body: The unique identifiers of the relationTypes
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_relation_types_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.remove_relation_types_with_http_info(**kwargs)  # noqa: E501
            return data

    def remove_relation_types_with_http_info(self, **kwargs):  # noqa: E501
        """Removes multiple relation types.  # noqa: E501

        Removes multiple relation types identified by the UUIDs passed as parameter.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_relation_types_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] body: The unique identifiers of the relationTypes
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_relation_types" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/relationTypes/bulk', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
